// This file was generated by Dashcode from Apple Computer, Inc.
// You may edit this file to customize your Dashboard widget.

function CommandMonitor()
{
	this.timeOut = 300;
	this.restartAfter = 60;
}

CommandMonitor.prototype.start = function ()
{
	if (this.commandLine != null) {
		if (this.systemCommand != null) {
			alert("Warning: attempt to re-enter command " + this.commandLine);
			this.stop();
		}

		var self = this;
		var onFinished = function (command) { self.finishedHandler(command); };
		var onOutput = function (output) { self.outputHandler(output); };

		this.startWatchdogTimer();
		this.systemCommand = widget.system(this.commandLine, onFinished);
		this.systemCommand.onreadoutput = onOutput;
	}
}

CommandMonitor.prototype.startAfterInterval = function ()
{
	if (this.restartAfter != null) {
		if (this.startTimer != null) {
			clearTimeout(this.startTimer);
		}

		var self = this;
		this.startTimer = setTimeout(function () {
			delete self.startInterval;
			self.start();
		}, this.restartAfter * 1000);
	}
}

CommandMonitor.prototype.startWatchdogTimer = function ()
{
	this.stopWatchdogTimer();

	var self = this;
	this.watchdogTimer = setTimeout(function () { self.watchdogTimeout(); }, this.timeOut * 1000);
}

CommandMonitor.prototype.stopWatchdogTimer = function ()
{
	if (this.watchdogTimer != null) {
		clearTimeout(this.watchdogTimer);
		delete this.watchdogTimer;
	}
}

CommandMonitor.prototype.watchdogTimeout = function ()
{
	alert("watchdog timeout");
	delete this.watchdogTimer;
	this.cancel();
}

CommandMonitor.prototype.outputHandler = function (output)
{
	this.stopWatchdogTimer();
	this.processLines(output);
	this.startWatchdogTimer();
}

CommandMonitor.prototype.processLines = function (lines)
{
	if (lines != null && lines.length > 0) {
		// Normalize line endings
		lines = lines.replace(/(\x0d\x0a)+/g, "\x0a");

		var match;
		var line_pat = /^.+$/mg;
		while ((match = line_pat.exec(lines)) != null) {
			var line = match[0];
			this.processLine(line);
		}
	}
}

CommandMonitor.prototype.processLine = function (line)
{
	// alert("Virtual processLine: " + line);
}

CommandMonitor.prototype.finishedHandler = function (command)
{
	// alert("finished");
	this.stopWatchdogTimer();
	this.processLines(command.outputString);
	delete this.systemCommand;
	this.startAfterInterval();
}

CommandMonitor.prototype.stop = function ()
{
	this.stopWatchdogTimer();
	
	if (this.startTimer != null) {
		clearTimeout(this.startTimer);
		delete this.startTimer;
	}
	
	if (this.systemCommand != null) {
		this.systemCommand.cancel();
		delete this.systemCommand;
	}
}

CommandMonitor.prototype.cancel = function ()
{
	this.stop();
	this.startAfterInterval();
}

// PostqueueMonitor

function PostqueueMonitor (frequency) {
	this.commandLine = "/usr/sbin/postqueue -p | /usr/bin/tail -n 1";
	this.restartAfter = frequency;
}

PostqueueMonitor.prototype = new CommandMonitor();

PostqueueMonitor.prototype.processLine = function (line)
{
	// no mail = "Mail queue is empty"
	// mail in queue = "-- [X] Kbytes in [Y] Requests."

	// Take off leading and trailing spaces
	line = line.replace(/^\s+/, "");
	line = line.replace(/\s+$/, "");

	// Look for a line of numbers	
	var match;
	if ((match = line.match(/in ([0-9]+) Request/)) != null) {
		var n = match[1];
		alert("current queue = " + n);
		if (this.ioCallback != null) {
			this.ioCallback(n);
		}
	}
	else if ((match = line.match(/Mail queue is empty/)) != null) {
		alert("mail queue is empty");
		if (this.ioCallback != null) {
			this.ioCallback("0");
		}
	}
	else  {
		alert("bad postqueue synatx: " + line);
		if (this.ioCallback != null) {
			this.ioCallback("--");
		}
	}
}

